Package: diffGeneAnalysis
Title: Performs differential gene expression Analysis
Version: 1.94.0
Author: Choudary Jagarlamudi
Description: Analyze microarray data
Maintainer: Choudary Jagarlamudi <choudary.jagar@swosu.edu>
License: GPL
Collate: dataTrim.R curveFit.R normalize.R biasAdjust.R assocAnalysis.R
        refGroup.R
Imports: graphics, grDevices, minpack.lm (>= 1.0-4), stats, utils
biocViews: Microarray, DifferentialExpression
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:31:17 UTC
RemoteUrl: https://github.com/bioc/diffGeneAnalysis
RemoteRef: RELEASE_3_23
RemoteSha: 083d0691a02c71e9ffc9c4f63830914fdb7efaa0
NeedsCompilation: no
Packaged: 2026-04-29 20:57:38 UTC; root
Built: R 4.6.0; ; 2026-04-29 21:28:45 UTC; unix
